//******************************************************************************
//                  PIN MANAGER FILE FOR PIC16F1789                            *
//                  *******************************                            *
//   This file is used to set the port pins of the  PIC16F1789                 *
//                                                                             *
//******************************************************************************
//                                                                             *
//   Filename:      PIC16F1789_Pin_Manager.h                                                 *
//   Date:          04/01/2014                                                 *
//   File Version:  Ver 1.0                                                    *
//                                                                             *
//   Author:        Simon O'Farrell                                            *
//                                                                             *
//                                                                             *
//******************************************************************************
//                                                                             *
//   Files required:                                                           *
//                   <xc.h>                                                    *
//                   <stdint.h>                                                *
//                                                                             *
//                                                                             *
//******************************************************************************
//                                                                             *
//                                                                             *
//                               PIC16F1789 PINOUT                             *
//                               *****************                             *
//                                  __________                                 *
//                                 |          |                                *
//                 +5v ------!MCLR |1       40| RB7(PGD)-- (ICSP)              *
//    (ADC NTC MOSFET) ------I-RA0 |2       39| RB6(PGC)-- (ICSP)              *
//  (ADC CURRENT LOAD) ------|-RA1 |3       38| RB5-|----- (Unused)            *
//  (ADC VOLTAGE LOAD) ------|-RA2 |4       37| RB4-|----- (Unused)            *
//            (Unused) ------|-RA3 |5       36| RB3------I-ENCODER - (Current) *
//            (Unused) ------|-RA4 |6       35| RB2------I-ENCODER - (Current) *
//            (Unused) ------|-RA5 |7       34| RB1-O----- (Unused)            *
//            (Unused) ------|-RE0 |8       33| RB0/INT--  (ENC - SW)          *
//            (Unused) ------|-RE1 |9       32| VDD  ----- +5v                 *
//            (Unused) ------|-RE2 |10      31| VSS  ----- GND                 *
//                 +5v ------  VDD |11      30| RD7-O----- LCD_DB7(LCD pin 14) *
//                 GND ------  VSS |12      29| RD6-O----- LCD_DB6(LCD pin 13) *
//            (Unused) ------ OSC1 |13      28| RD5-O----- LCD_DB5(LCD pin 12) *
//            (Unused) ------ OSC2 |14      27| RD4-O----- LCD_DB4(LCD pin 11) *
//         (SPI Clock) ------  RC0 |15      26| RC7-|----- (Unused)            *
//          (SPI Data) ------|-RC1 |16      25| RC6-|----- (Unused)            *
//          (SPI SYNC) ------|-RC2 |17      24| RC5-|----- (Unused)            *
//            (Unused) ------|-RC3 |18      23| RC4-|----- (Unused)            *
//  LCD_rs (LCD pin 4) ------O-RD0 |19      22| RD3 |----- (Unused)            *
//  LCD_rw (LCD pin 5) ------O-RD1 |20      21| RD2-O----- LCD_e - (LCD pin 6) *
//                                 |__________|                                *
//                                                                             *
//******************************************************************************

#ifndef PIC16F1789_PIN_MMANAGER_H
#define	PIC16F1789_PIN_MMANAGER_H
#include <xc.h>

// --> P I C 1 6 F 1 7 8 9   A S S I G N M E N T S <--
// --> A D C <--

#define ADC_PORT                       PORTA
#define ADC_TRIS                       TRISA

#define ADC_NTC_MOSFET                 PORTAbits.RA0
#define ADC_CURRENT                    PORTAbits.RA1
#define ADC_VOLTAGE                    PORTAbits.RA2





// --> L C D   P I N   A S S I G N M E N T S <--

#define LCD_READ_DATA_PORT 	           PORTD
#define LCD_WRITE_DATA_PORT            LATD
#define LCD_DATA_TRIS 	               TRISD


#define LCD_READ_RS                    PORTDbits.RD0
#define LCD_WRITE_RS                   LATDbits.LATD0
#define LCD_RS_TRIS                    TRISDbits.TRISD0

#define LCD_READ_RW                    PORTDbits.RD1
#define LCD_WRITE_RW                   LATDbits.LATD1
#define LCD_RW_TRIS                    TRISDbits.TRISD1

#define LCD_READ_E                     PORTDbits.RD2
#define LCD_WRITE_E                    LATDbits.LATD2
#define LCD_E_TRIS                     TRISDbits.TRISD2

#define LCD_READ_BF                    PORTDbits.RD7
#define LCD_WRITE_BF                   LATDbits.LATD7
#define LCD_BF_TRIS                    TRISDbits.TRISD7


// --> R O T A R Y   E N C O D E R  P I N   A S S I G N M E N T S <--

#define ENCODER_PORT                   PORTB

#define ENCODER_TRIS_V_S               TRISBbits.TRISB0
#define ENCODER_TRIS_1                 TRISBbits.TRISB2
#define ENCODER_TRIS_2                 TRISBbits.TRISB3

#define SWITCH                         PORTBbits.RB0

#define PIN_1                          PORTBbits.RB3
#define PIN_2                          PORTBbits.RB2




// --> M C P 4 9 2 2   P I N   A S S I G N M E N T S <--

// Define the port the DAC uses.

#define DAC_WRITE_PORT                 LATC

// Define DAC CS signal.
#define DAC_WRITE_CS                   LATCbits.LATC0

// Define DAC CLK signal.
#define DAC_WRITE_CLK                  LATCbits.LATC1

// Define DAC DATA signal.
#define DAC_WRITE_DATA                 LATCbits.LATC2

// Define DAC SDO signal.
#define DAC_WRITE_LDAC                 LATCbits.LATC3


#endif	// --> H A R D W A R E _ H <--